@@ -20,6 +20,6 @@ def load_fixture(filename: str) -> Dict[Any, Any]:
     :return: Dict
     """
     file_path = Path.cwd().joinpath("tests", "fixtures", filename)
-    with open(str(file_path)) as file:
+    with open(str(file_path), encoding="UTF-8") as file:
         fixture = json.load(file)
     return fixture
