@@ -73,20 +73,20 @@ class SecretManager:
             for secret in all_secrets["SecretList"]
             if f"{self.current_environment}/snatch" in secret["Name"]
         ]
-        logger.debug(f"All Keys found: {all_keys}")
+        logger.info(f"All Keys found: {all_keys}")
         project_keys = [
             secret
             for secret in all_keys
             if f"{self.current_environment}/snatch" in secret
         ]
-        logger.debug(f"Project Keys found: {project_keys}")
+        logger.info(f"Project Keys found: {project_keys}")
         return project_keys
 
     def get_project_secrets(self) -> Dict[Any, Any]:
         secrets_manager_data = {}
         needed_secrets = self._get_available_secrets()
         for secret in needed_secrets:
-            logger.debug(f"Reading Secret: {secret} ...")
+            logger.info(f"Reading Secret: {secret} ...")
             secret_name = secret.split("/")[-1]
             secret_data = {secret_name: None}
             response = self.client.get_secret_value(SecretId=secret)
